# -*- coding: utf-8 -*-
# Copyright (C) 2020 Caitum Technologies

from setuptools import setup, find_packages


setup(
    name='caitk',
    version='0.0.1',
    description='Caitum Artificial Intelligence Toolkit',
    license='GPL-3.0-only',

    packages=find_packages(),
    install_requires=[],

    include_package_data=True,
    zip_safe=True
)
